@@ -56,6 +56,7 @@ pub fn build_l2_tcp_packet(
     dst_ip: &Ipv4Addr,
     src_port: u16,
     dst_port: u16,
+    seq: u32,
     rng: &mut ThreadRng,
 ) {
     // L2
@@ -83,7 +84,7 @@ pub fn build_l2_tcp_packet(
 
     // L4
     if let Some(mut tcp_header) = MutableTcpPacket::new(&mut tx_packet[(14 + 20)..]) {
-        build_l4_tcp_packet(&mut tcp_header, src_ip, dst_ip, src_port, dst_port, rng);
+        build_l4_tcp_packet(&mut tcp_header, src_ip, dst_ip, src_port, dst_port, seq, rng);
     }
 }
 
@@ -94,11 +95,12 @@ pub fn build_l4_tcp_packet(
     dst_ip: &Ipv4Addr,
     src_port: u16,
     dst_port: u16,
+    seq: u32,
     rng: &mut ThreadRng,
 ) {
     tx_packet.set_source(src_port);
     tx_packet.set_destination(dst_port);
-    tx_packet.set_sequence(rng.gen::<u32>());
+    tx_packet.set_sequence(seq);
     tx_packet.set_acknowledgement(0);
     tx_packet.set_flags(TcpFlags::SYN);
     tx_packet.set_window(30000 + (rng.gen::<u8>() as u16 * 17));
@@ -148,6 +150,7 @@ pub fn send_tcp<F>(
     dst_ip: &Ipv4Addr,
     src_port: u16,
     dst_port: u16,
+    seq: u32,
     rng: &mut ThreadRng,
     modify_packet_func: F,
 ) -> Result<(), anyhow::Error>
@@ -158,7 +161,7 @@ where
     if let None = tx.build_and_send(1, 14 + 20 + 20 + body_size, &mut |tx_packet: &mut [u8]| {
         // Step0. 构造 TCP 报文
         build_l2_tcp_packet(
-            tx_packet, body_size, src_mac, dst_mac, src_ip, dst_ip, src_port, dst_port, rng,
+            tx_packet, body_size, src_mac, dst_mac, src_ip, dst_ip, src_port, dst_port, seq, rng,
         );
         // Step1. 修改构造好的 TCP 报文, 计算校验和
         if modify_packet_func(tx_packet) {
